@@ -7,9 +7,11 @@ from django.utils.encoding import force_bytes
 from django.utils.http import urlsafe_base64_encode
 from mock import patch
 from rest_framework import status
+from rest_framework.authtoken.models import Token
 
 from user_management.api import views
 from user_management.models.tests.factories import UserFactory
+from user_management.models.tests.models import BasicUser
 from user_management.models.tests.utils import APIRequestTestCase
 
 
@@ -17,6 +19,21 @@ User = get_user_model()
 TEST_SERVER = 'http://testserver'
 
 
+class GetTokenTest(APIRequestTestCase):
+    view_class = views.GetToken
+
+    def test_delete(self):
+        user = UserFactory.create()
+        token = Token.objects.create(user=user)
+
+        request = self.create_request('delete', user=user)
+        response = self.view_class.as_view()(request)
+        self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
+
+        with self.assertRaises(Token.DoesNotExist):
+            Token.objects.get(pk=token.pk)
+
+
 class TestRegisterView(APIRequestTestCase):
     view_class = views.UserRegister
 
@@ -38,8 +55,13 @@ class TestRegisterView(APIRequestTestCase):
     def test_unauthenticated_user_post(self):
         """Unauthenticated Users should be able to register."""
         request = self.create_request('post', auth=False, data=self.data)
-        response = self.view_class.as_view()(request)
+
+        send_email_path = 'user_management.models.mixins.VerifyEmailMixin.send_validation_email'
+        with patch(send_email_path) as send:
+            response = self.view_class.as_view()(request)
+
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
+        send.assert_called_once_with()
 
         user = User.objects.get()
         self.assertEqual(user.name, self.data['name'])
@@ -50,6 +72,19 @@ class TestRegisterView(APIRequestTestCase):
         # Password should validate
         self.assertTrue(check_password(self.data['password'], user.password))
 
+    @patch('user_management.api.serializers.RegistrationSerializer.Meta.model',
+           new=BasicUser)
+    def test_unauthenticated_user_post_no_verify_email(self):
+        """An email should not be sent if email_verification_required is False."""
+        request = self.create_request('post', auth=False, data=self.data)
+
+        send_email_path = 'user_management.models.mixins.VerifyEmailMixin.send_validation_email'
+        with patch(send_email_path) as send:
+            response = self.view_class.as_view()(request)
+
+        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
+        self.assertFalse(send.called)
+
     def test_post_with_missing_data(self):
         """Password should not be sent back on failed request."""
         self.data.pop('name')
@@ -133,7 +168,8 @@ class TestPasswordResetEmail(APIRequestTestCase):
         user = UserFactory.create(
             email=email,
             # Don't send the verification email
-            verified_email=True)
+            email_verification_required=False,
+        )
 
         self.view_class().send_email(user)
 
@@ -352,10 +388,10 @@ class TestVerifyAccountView(APIRequestTestCase):
         request = self.create_request('post', auth=True)
         view = self.view_class.as_view()
         response = view(request, uidb64=uid, token=token)
-        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
         updated_user = User.objects.get(pk=user.pk)
-        self.assertTrue(updated_user.verified_email)
+        self.assertFalse(updated_user.email_verification_required)
         self.assertTrue(updated_user.is_active)
 
     def test_post_unauthenticated(self):
@@ -366,10 +402,10 @@ class TestVerifyAccountView(APIRequestTestCase):
         request = self.create_request('post', auth=False)
         view = self.view_class.as_view()
         response = view(request, uidb64=uid, token=token)
-        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
         updated_user = User.objects.get(pk=user.pk)
-        self.assertTrue(updated_user.verified_email)
+        self.assertFalse(updated_user.email_verification_required)
         self.assertTrue(updated_user.is_active)
 
     def test_post_invalid_user(self):
@@ -393,7 +429,7 @@ class TestVerifyAccountView(APIRequestTestCase):
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_post_verified_email(self):
-        user = UserFactory.create(verified_email=True)
+        user = UserFactory.create(email_verification_required=False)
         token = default_token_generator.make_token(user)
         uid = urlsafe_base64_encode(force_bytes(user.pk))
 
@@ -411,13 +447,13 @@ class TestVerifyAccountView(APIRequestTestCase):
         request = self.create_request('post', user=other_user)
         view = self.view_class.as_view()
         response = view(request, uidb64=uid, token=token)
-        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
         updated_user = User.objects.get(pk=user.pk)
-        self.assertTrue(updated_user.verified_email)
+        self.assertFalse(updated_user.email_verification_required)
 
         logged_in_user = User.objects.get(pk=other_user.pk)
-        self.assertFalse(logged_in_user.verified_email)
+        self.assertTrue(logged_in_user.email_verification_required)
 
 
 class TestProfileDetail(APIRequestTestCase):
